==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/ro.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Gestionați Parametrii Lightbox gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "gestionaţi Galerie");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Imagine intreaga Lățime");
define('MANAGE_GALLERY_FULL_HEIGHT', "Imagine intreaga Inaltime");
define('MANAGE_GALLERY_THUMB_WIDTH', "Miniatură Lățimea imaginii");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Înălțimea imaginii miniatură");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Păstra degetul mare Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Afișați titlurile");
define('MANAGE_GALLERY_DISABLE_SORT', "Dezactivați Sort");
define('MANAGE_GALLERY_DELETE_IMAGE', "ştergeţi imaginea");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Salvați Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Faceți clic pe &quot;Actualizare&quot; pentru a publica <br /> imaginile încărcate tale.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Toate imaginile au fost redimensionate și setări au fost salvate.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "A apărut o eroare la redimensionarea imaginilor sau salvarea setărilor.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Imaginea dvs. (e) a fost încărcat.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "A apărut o eroare la încărcarea imaginii (e).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Fișierul pe care încercați să îl încărcați nu este o imagine.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Fișierul pe care încercați să încărcați este prea mare.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Titlul a fost salvat.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Sunteți sigur că doriți să ștergeți imaginea");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Imaginea a fost ștearsă.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "A apărut o eroare la ștergerea imaginii.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Se salvează parametrii și redimensionarea imaginilor, vă rugăm să așteptați ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Se încarcă, vă rugăm să așteptați ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Ordinea de sortare nu a fost salvat. Doriți să salvați ordinea de sortare?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Ordinea de sortare a imaginii a fost salvată.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "A apărut o eroare la salvarea fel de imagine de eroare.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/ro.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Gestionați Parametrii Lightbox gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "gestionaţi Galerie");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Imagine intreaga Lățime");
define('MANAGE_GALLERY_FULL_HEIGHT', "Imagine intreaga Inaltime");
define('MANAGE_GALLERY_THUMB_WIDTH', "Miniatură Lățimea imaginii");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Înălțimea imaginii miniatură");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Păstra degetul mare Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Afișați titlurile");
define('MANAGE_GALLERY_DISABLE_SORT', "Dezactivați Sort");
define('MANAGE_GALLERY_DELETE_IMAGE', "ştergeţi imaginea");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Salvați Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Faceți clic pe &quot;Actualizare&quot; pentru a publica <br /> imaginile încărcate tale.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Toate imaginile au fost redimensionate și setări au fost salvate.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "A apărut o eroare la redimensionarea imaginilor sau salvarea setărilor.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Imaginea dvs. (e) a fost încărcat.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "A apărut o eroare la încărcarea imaginii (e).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Fișierul pe care încercați să îl încărcați nu este o imagine.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Fișierul pe care încercați să încărcați este prea mare.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Titlul a fost salvat.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Sunteți sigur că doriți să ștergeți imaginea");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Imaginea a fost ștearsă.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "A apărut o eroare la ștergerea imaginii.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Se salvează parametrii și redimensionarea imaginilor, vă rugăm să așteptați ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Se încarcă, vă rugăm să așteptați ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Ordinea de sortare nu a fost salvat. Doriți să salvați ordinea de sortare?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Ordinea de sortare a imaginii a fost salvată.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "A apărut o eroare la salvarea fel de imagine de eroare.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Fișierul pe care încercați să îl încărcați este mai mare decât setările PHP „upload_max_filesize” sau „post_max_size”. Contactați administratorul de sistem pentru a crește aceste limite.");
?>
